@@ -27,13 +27,15 @@ import (
 
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
-	"sigs.k8s.io/cli-utils/pkg/kstatus/polling"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/kustomize/api/konfig"
 
-	"github.com/fluxcd/flux2/v2/pkg/manifestgen/kustomization"
+	"github.com/fluxcd/cli-utils/pkg/kstatus/polling"
 	runclient "github.com/fluxcd/pkg/runtime/client"
 	"github.com/fluxcd/pkg/ssa"
+	ssautil "github.com/fluxcd/pkg/ssa/utils"
+
+	"github.com/fluxcd/flux2/v2/pkg/manifestgen/kustomization"
 )
 
 // Apply is the equivalent of 'kubectl apply --server-side -f'.
@@ -61,7 +63,7 @@ func Apply(ctx context.Context, rcg genericclioptions.RESTClientGetter, opts *ru
 	var stageTwo []*unstructured.Unstructured
 
 	for _, u := range objs {
-		if ssa.IsClusterDefinition(u) {
+		if ssautil.IsClusterDefinition(u) {
 			stageOne = append(stageOne, u)
 		} else {
 			stageTwo = append(stageTwo, u)
@@ -76,8 +78,10 @@ func Apply(ctx context.Context, rcg genericclioptions.RESTClientGetter, opts *ru
 		changeSet.Append(cs.Entries)
 	}
 
-	if err := waitForSet(rcg, opts, changeSet); err != nil {
-		return "", err
+	if len(changeSet.Entries) > 0 {
+		if err := waitForSet(rcg, opts, changeSet); err != nil {
+			return "", err
+		}
 	}
 
 	if len(stageTwo) > 0 {
@@ -105,7 +109,7 @@ func readObjects(root, manifestPath string) ([]*unstructured.Unstructured, error
 		if err != nil {
 			return nil, err
 		}
-		return ssa.ReadObjects(bytes.NewReader(resources))
+		return ssautil.ReadObjects(bytes.NewReader(resources))
 	}
 
 	ms, err := os.Open(manifestPath)
@@ -114,7 +118,7 @@ func readObjects(root, manifestPath string) ([]*unstructured.Unstructured, error
 	}
 	defer ms.Close()
 
-	return ssa.ReadObjects(bufio.NewReader(ms))
+	return ssautil.ReadObjects(bufio.NewReader(ms))
 }
 
 func newManager(rcg genericclioptions.RESTClientGetter, opts *runclient.Options) (*ssa.ResourceManager, error) {
